fix.geoid: fix.geoid

View source: R/region-reorg-fcns.R

fix.geoidR Documentation

fix.geoid

Description

Adds leading 0s if necessary and ensures that a given vector is a character vector. Fixes geoids of any type that may have been read as numeric and turns into valid identifiers.

Usage

fix.geoid(x, width = NULL)

Arguments

x

a vector of identifiers that can be coerced to character

width

If NULL, pads until all elements have width equal to the maximum width in vector. Otherwise, a numeric specifying width


kmcd39/geox documentation built on Nov. 15, 2024, 2:03 a.m.