| parks.wrapper | R Documentation |
Gets parks in a state, based on census bureau data. Can query from sf object x or state fp codes.
parks.wrapper(x = NULL, .statefps = NULL, ...)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.