View source: R/region-reorg-fcns.R
| fix.geoid | R Documentation |
Adds leading 0s if necessary and ensures that a given vector is a character vector. Fixes geoids of any type that may have been read as numeric and turns into valid identifiers.
fix.geoid(x, width = NULL)
x |
a vector of identifiers that can be coerced to character |
width |
If NULL, pads until all elements have width equal to the maximum width in vector. Otherwise, a numeric specifying width |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.